#
# spec file for package yast2-schema
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor micro%nil

%if "%flavor" == ""
Name:           yast2-schema
%else
Name:           yast2-schema-%{flavor}
%endif

Version:        5.0.1
Release:        1.8

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source0:        yast2-schema-%{version}.tar.bz2

Group:          System/YaST
License:        GPL-2.0-or-later
URL:            https://github.com/yast/yast-schema

Provides:       yast2-schema = %{version}
# others cannot be used as it contains same files
Conflicts:      yast2-schema
Obsoletes:      yast2-schema < 4.4.9

# Dependencies needed to build the package
BuildRequires:  jing
BuildRequires:  libxml2-tools
BuildRequires:  trang
BuildRequires:  yast2-devtools

# All packages providing RNG files for AutoYaST
# in /usr/share/YaST2/schema/autoyast/rng/*.rng

# LUKS-related elements in the partitioning schema
BuildRequires:  autoyast2 >= 5.0.1
BuildRequires:  yast2
# add_on_products and add_on_others types
BuildRequires:  yast2-add-on >= 4.3.3
# set 't' element in 'initrd_module' element
BuildRequires:  yast2-bootloader >= 4.3.12
BuildRequires:  yast2-configuration-management >= 4.3.0
BuildRequires:  yast2-country >= 4.3.0
# Added fcoe-client schema
BuildRequires:  yast2-fcoe-client >= 4.4.2
BuildRequires:  yast2-kdump
# add route 'extrapara' element
BuildRequires:  yast2-network >= 4.5.4

# registration is available only where suse connect is also available
%ifnarch s390 %ix86
# addons: architecture/version is optional
BuildRequires:  yast2-registration >= 4.3.12
%endif

# Add support for security policies ('security_policy')
BuildRequires:  yast2-security >= 4.5.3
BuildRequires:  yast2-services-manager
# tag home_btrfs_subvolume
BuildRequires:  yast2-users >= 4.1.11

# flavor specific dependencies
%if "%flavor" != "micro"
BuildRequires:  yast2-audit-laf >= 4.3.0
BuildRequires:  yast2-auth-client >= 4.3.0
BuildRequires:  yast2-auth-server
# YaST DNS server package and modules depending on it is dropped from TW
# (bsc#1205363)
%if 0%{?sle_version}
BuildRequires:  yast2-dhcp-server >= 4.3.0
# allow 'zone' instead of 'listentry'
BuildRequires:  yast2-dns-server >= 4.3.3
BuildRequires:  yast2-firewall >= 4.3.0
BuildRequires:  yast2-firstboot >= 4.3.0
BuildRequires:  yast2-ftp-server >= 4.3.0
BuildRequires:  yast2-geo-cluster >= 4.3.0
BuildRequires:  yast2-http-server
BuildRequires:  yast2-installation
BuildRequires:  yast2-tftp-server >= 4.1.7
# add 'iface' element
BuildRequires:  yast2-iscsi-client >= 4.3.3
BuildRequires:  yast2-mail >= 4.3.3
BuildRequires:  yast2-nfs-client
BuildRequires:  yast2-nfs-server
# YaST NIS packages are dropped from TW (bsc#1183893)
%if 0%{?sle_version}
BuildRequires:  yast2-nis-client
BuildRequires:  yast2-nis-server
%endif
BuildRequires:  yast2-ntp-client
# nested category_filter (bsc#1198848)
BuildRequires:  yast2-online-update-configuration >= 4.5.1
BuildRequires:  yast2-printer
BuildRequires:  yast2-proxy
# Package available for S390 only
%ifarch s390 s390x
BuildRequires:  yast2-s390
%endif
BuildRequires:  yast2-samba-client
BuildRequires:  yast2-samba-server
# YaST sound packages are dropped from TW (bsc#1206903)
%if 0%{?sle_version}
BuildRequires:  yast2-sound
%endif
BuildRequires:  yast2-squid
BuildRequires:  yast2-sysconfig
%endif
%endif

#!BuildIgnore: yast2-build-test

# optimization suggested by AJ:
#!BuildIgnore: tomcat5

# ignoring conflicting packages
#!BuildIgnore: yast2-branding-SLED yast2-branding-openSUSE
#!BuildIgnore: yast2-theme yast2-theme-SLED yast2-theme-openSUSE yast2-theme-SLE

# Hotfix to build a package, bnc #427684
#!BuildIgnore: xerces-j2-bootstrap libusb-0_1-4 crimson

# To speedup && to easily recover from dependency hell
#!BuildIgnore: yast2-pkg-bindings zypper libzypp yast2-gtk yast2-qt yast2-ncurses yast2-qt-pkg yast2-ncurses-pkg

# Yast packages without AutoYast support
#!BuildIgnore: yast2-country-data
#!BuildIgnore: yast2-control-center yast2-control-center-gnome yast2-control-center-qt

%if "%flavor" != ""
Summary:        YaST2 - AutoYaST Schema (%flavor variant)

%description
AutoYaST Syntax Schema (%flavor variant)
%else
Summary:        YaST2 - AutoYaST Schema

%description
AutoYaST Syntax Schema
%endif

%prep
%setup -n yast2-schema-%{version}

%build
%yast_build

%install
%yast_install

%if "%flavor" != ""
# rename the doc dir according to the current flavor
mv %{buildroot}/%{_docdir}/yast2-schema %{buildroot}/%{_docdir}/%{name}
%endif

%files
%defattr(-,root,root)
%dir %{yast_schemadir}/autoyast/rnc
%{yast_schemadir}/autoyast/rnc/profile.rnc
%{yast_schemadir}/autoyast/rnc/includes.rnc
%dir %{yast_schemadir}/autoyast/rng
%{yast_schemadir}/autoyast/rng/*.rng
%doc %{yast_docdir}
%license COPYING

%changelog
* Fri Sep 22 2023 Ancor Gonzalez Sosa <ancor@suse.com>
- Added several LUKS-related elements to the partitioning schema
  (jsc#PED-3878, jsc#PED-5518).
- 5.0.1
* Wed Aug 30 2023 Josef Reidinger <jreidinger@suse.cz>
- 5.0.0 (#bsc1185510)
* Fri Mar  3 2023 Ladislav Slezák <lslezak@suse.cz>
- Bump version to 4.6.0 (bsc#1208913)
* Tue Feb  7 2023 Josef Reidinger <jreidinger@suse.com>
- drop yast2-dhcp-server and yast2-http-server schema from TW as
  it also depends on yast2-dns-server (bsc#1205363)
- 4.5.9
* Mon Feb  6 2023 Josef Reidinger <jreidinger@suse.com>
- drop yast2-dns-server schema from TW (bsc#1205363)
- 4.5.8
* Mon Jan 23 2023 Josef Reidinger <jreidinger@suse.com>
- drop yast2-sound schema spec from TW where yast2-sound is dropped
  (bsc#1206903)
- 4.5.7
* Thu Nov  3 2022 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add support for security policies validation (jsc#SLE-24764).
- Synchronize SP4 and master branches (related to bsc#1199165).
- 4.5.6
* Fri Aug 12 2022 David Diaz <dgonzalez@suse.com>
- Add KDUMP_AUTO_RESIZE element in kdump section
  (related to jsc#SLE-18441 and gh#yast/yast-kdump#123).
- 4.5.5
* Mon Jul  4 2022 Knut Anderssen <kanderssen@suse.com>
- Add 'extrapara' to routes in the networking section (bsc#1201129)
- 4.5.4
* Thu May 26 2022 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Support for flatten and nested "category_filter" element in the
  "online_update_configuration" section (bsc#1198848).
- 4.5.3
* Mon Apr 11 2022 Ladislav Slezák <lslezak@suse.cz>
- Fix up for the previous change (related to bsc#1183893)
- 4.5.2
* Fri Apr  8 2022 José Iván López González <jlopez@suse.com>
- Remove dependency of YaST NIS packages from TW (bsc#1183893).
- 4.5.1
* Wed Apr  6 2022 Ladislav Slezák <lslezak@suse.cz>
- Bump version to 4.5.0 (bsc#1198109)
* Fri Feb 18 2022 Knut Anderssen <kanderssen@suse.com>
- Added fcoe-client schema (bsc#1194895)
- 4.4.11
* Wed Jan 26 2022 Knut Anderssen <kanderssen@suse.com>
- Removed 'lsm' section adding just the 'lsm_select' element to the
  security section (related to jsc#SLE-22069).
- 4.4.10
* Tue Jan 25 2022 Josef Reidinger <jreidinger@suse.com>
- Split the package into yast2-schema-default and
  yast2-schema-micro to respect limited set of modules in Micro
  product (jsc#SLE-18820)
- 4.4.9
* Tue Jan 11 2022 Knut Anderssen <kanderssen@suse.com>
- Added lsm 'none' section to the security schema (jsc#SLE-22069)
- 4.4.8
* Fri Dec 24 2021 Knut Anderssen <kanderssen@suse.com>
- Added 'lsm' section to the security schema (jsc#SLE-22069)
- 4.4.7
* Fri Nov 19 2021 Knut Anderssen <kanderssen@suse.com>
- Add 'efi' element to the rules schema (jsc#SLE-18819)
- 4.4.6
* Thu Nov  4 2021 Knut Anderssen <kanderssen@suse.com>
- Add 'description' to the interfaces in the networking section
  (bsc#1192270).
- 4.4.5
* Mon Oct 25 2021 Knut Anderssen <kanderssen@suse.com>
- Add the "keep_unknown_lv" element to the partitioning schema
  (bsc#1191968).
- 4.4.4
* Tue Sep 21 2021 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add the "hostname" element to the rules schema (bsc#1190696).
- 4.4.3
* Tue May 11 2021 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Consider 'static_text' as a valid value for 'ask/type' elements
  (bsc#1185909).
- Update the 'script' and 'default_value_script' elements in
  'ask' sections (bsc#1185704).
- 4.4.2
* Wed May  5 2021 Knut Anderssen <kanderssen@suse.com>
- Add the 'backend' element to the networking section (bsc#1183886)
- 4.4.1
* Mon Apr  5 2021 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add the 'mkfs_options' element to the 'partition' section
  (bsc#1184268).
- 4.4.0
* Thu Mar 11 2021 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Allow the interfaces list in the profile to be  empty
  (bsc#1183257).
- Remove the 'haspcmica' element from the schema (related to
  bsc#1183352).
- 4.3.21
* Wed Mar  3 2021 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Allow using 'zone' instead of 'listentry' in the list of zones
  (bsc#1181718).
- 4.3.20
* Wed Mar  3 2021 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add 'bridge_forward_delay' to the interfaces in the networking
  section (bsc#1180944).
- Add 'iface' element to the targets in the iSCSI section
  (bsc#1182193).
- 4.3.19
* Wed Feb 10 2021 Knut Anderssen <kanderssen@suse.com>
- Add the 'virt_bridge_proposal' element to the networking section
  in order to permit to disable the proposal of the bridge network
  configuration for virtualization (bsc#1178603).
- 4.3.18
* Tue Feb  2 2021 Knut Anderssen <kanderssen@suse.com>
- Add the 'lladdr' element to the networking interface section
  (bsc#1179876).
- 4.3.17
* Mon Dec 14 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add support for Btrfs quotas (jsc#SLE-7742).
- 4.3.16
* Tue Oct 20 2020 schubi@suse.de
- Registration/Addons: Architecture and version are optional.
  (jsc#SLE-16195).
- 4.3.15
* Tue Oct 13 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Allow setting the 't' (or 'config:type') attribute in:
  - 'backup' and 'upgrade' elements (bsc#1176834 and bsc#1176848).
  - 'initrd_module' element (bsc#1177058).
- 4.3.14
* Fri Oct  9 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- AutoYaST schema (bsc#1174133, bsc#1177496):
  - Fix validation of string/symbol elements in the schema.
  - Fix validation of 'masquerade_user' elements.
- 4.3.13
* Thu Oct  1 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Do not validate unknown sections (bsc#1177173).
- 4.3.12
* Thu Oct  1 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add validation of 'activate_systemd_default_target' and
  'final_restart_services' elements in the 'general/mode' section.
  (bsc#1176595).
- 4.3.11
* Tue Sep 29 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Drop the 'suse_btrfs' element from the schema (bsc#1176970).
- 4.3.10
* Tue Sep 29 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Drop the 'general/mouse' element from the schema (bsc#1176973).
- 4.3.9
* Thu Sep 24 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add the schema for 'backup' and 'upgrade' sections (bsc#1176834).
- 4.3.8
* Wed Sep 23 2020 Josef Reidinger <jreidinger@suse.com>
- add update_nvram element to the bootloader section (jsc#11500)
- 4.3.7
* Wed Sep  2 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Recognize installed_product and installed_product_version as
  legal elements of rules.xml files (boo#1176089).
- 4.3.6
* Mon Aug 24 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Element 'release_type' is not mandatory (bsc#1175682).
- 4.3.5
* Tue Jul 28 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Fix the schema definition for the add_on_products and
  add_on_others elements (boo#1174424).
- 4.3.4
* Thu Jul  2 2020 Knut Anderssen <kanderssen@suse.com>
- Make the report section elements optional as AutoYaST proposes
  default values when missing (bsc#1173312)
- 4.3.3
* Fri Jun 26 2020 Knut Anderssen <kanderssen@suse.com>
- Add the setup_before_proposal element to the networking section
  (bsc#1171922)
- 4.3.2
* Fri Jun  5 2020 Martin Vidner <mvidner@suse.com>
- Remove SUSE Linux 9.3 compatibility to improve error messages
  (bsc#1172578)
- Fix Jenkins build running into a Java out of memory error
- 4.3.1
* Thu May  7 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Allow optional types for string and map objects (bsc#1170886).
- Check schema correctness with jing and xmllint (bsc#1172131).
- 4.3.0
* Fri Apr 17 2020 Josef Reidinger <jreidinger@suse.com>
- Exclude the registration for architectures on which it does not
  build (related to the jsc#SLE-11852)
- 4.2.10
* Thu Apr 16 2020 Josef Reidinger <jreidinger@suse.com>
- Always add the registration to schema (jsc#SLE-11852)
- do not use exclude arch on SLE
- 4.2.9
* Tue Jan 21 2020 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Fix 'scripts' elements validation (bsc#1156905).
- 4.2.8
* Thu Dec 12 2019 schubi@suse.de
- Updated security rnc file (bsc#1158301)
- 4.2.7
* Wed Oct 30 2019 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update schema to support setting the encryption method through
  the 'crypt_method' (related to jsc#SLE-7376).
- 4.2.6
* Fri Oct 18 2019 schubi@suse.de
- Added extra_services to security.rnc file (bsc#1153623).
- 4.2.5
* Mon Oct  7 2019 Josef Reidinger <jreidinger@suse.com>
- Update yast2-bootloader dependency to support secure_boot flag
  (jsc#SLE-8787)
- 4.2.4
* Thu Sep 12 2019 schubi@suse.de
- Ignoring X-SuSE-YaST-AutoInstResourceAliases entries in desktop
  files while evaluating resources (bsc#1144894).
- 4.2.3
* Tue Aug 27 2019 schubi@suse.de
- Report warning if X_SuSE_YaST_AutoInstResource has not been set
  in desktop file (bsc#144894).
- 4.2.2
* Fri Aug  2 2019 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update autoyast2 and yast2-add-on dependencies to:
  - Support the new add_on_others section
  - Add the missing 'uuid' element in the 'partition' sections
- Fixes bsc#1144007.
- 4.2.1
* Tue May 21 2019 schubi@suse.de
- Updated build requ. due tag cpu_mitigations in bootloader.
  (bsc#1128707) (wrong version number)
- 4.2.0
* Tue May  7 2019 schubi@suse.de
- Updated build requ. due tag cpu_mitigations in bootloader.
  (bsc#1128707).
- 4.1.7
* Mon Mar 25 2019 schubi@suse.de
- Updated build requ. due tag smt in bootloader (bsc#1128707).
- 4.1.6
* Thu Mar 14 2019 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add Bcache related elements to the partitioning schema
  (fate#325346).
- 4.1.5
* Mon Mar 11 2019 schubi@suse.de
- Updated build requ. due tag home_btrfs_subvolume and smt.
  (bsc#1128707)
- 4.1.4
* Mon Feb  4 2019 schubi@suse.de
- Added yast2-tftp-server for autobuild (bsc#1123830).
- 4.1.3
* Tue Jan 29 2019 igonzalezsosa@suse.com
- Add dependency on yast2-configuration-management (fate#322722).
- 4.1.2
* Wed Jan 16 2019 jreidinger@suse.com
- AutoYaST schema changed in yast2-firewall (4.1.8).
  - Dropped unused elements that were not in GA and are not needed in
    SP1 (fate#324662)
- 4.1.1
* Tue Jan  8 2019 knut.anderssen@suse.com
- AutoYaST schema changed in yast2-firewall (4.1.4).
  - Allowed the new 'forward_ports', 'rich_rules' and
    'source_ports' elements in zone entries (bsc#1108199)
- 4.1.0
* Fri Dec 28 2018 schubi@suse.de
- Added new schema of yast2-tftp-server module (bsc#1108199).
- 4.0.7
* Fri Nov 30 2018 schubi@suse.de
- Evaluating which package belongs to which schema. This
  information will be stored in includes.rnc (bsc#1117068)
- 4.0.6
* Thu Nov 29 2018 schubi@suse.de
- yast2-firstboot change: Added firstboot.rnc file to desktop file.
  (bsc#1117068)
- 4.0.5
* Thu Nov 22 2018 schubi@suse.de
- AutoYaST schema changed in yast2-firewall (4.0.28).
  - Allowed the new 'description', 'short' and 'target' elements in
    zone entries (bsc#1108199)
- 4.0.4
* Tue Oct 16 2018 schubi@suse.de
- Added license file to spec.
* Wed Aug 22 2018 schubi@suse.de
- Switched license in spec file from SPDX2 to SPDX3 format.
* Wed May 23 2018 igonzalezsosa@suse.com
- Add create_subvolumes element (bsc#1094307)
- 4.0.3
* Tue Apr  3 2018 igonzalezsosa@suse.com
- Fix several validation problems (bsc#1013047)
- 4.0.2
* Mon Feb 12 2018 jreidinger@suse.com
- drop yast2-ca-management (fate#319119)
- 4.0.1
* Fri Feb  9 2018 knut.anderssen@suse.com
- Drop yast2-inetd (fate#323373)
- 4.0.0
* Fri Nov  4 2016 igonzalezsosa@suse.com
- Add support to enable copy-on-write for Btrfs subvolumes
  (FATE#320342)
- Add support to omit the Btrfs default subvolume name
  (FATE#317775)
- Add support to define SSH authorized_keys (FATE#319471)
- 3.2.0
* Thu Aug 25 2016 igonzalezsosa@suse.com
- Exclude i586 and s390 architectures as SLE 12 does not build
  a runnable kernel for such architectures (bsc#933411).
- 3.1.8
* Mon Jun  6 2016 igonzalezsosa@suse.com
- Add ssh_import section (fate#319624)
- 3.1.7
* Fri Nov 13 2015 igonzalezsosa@suse.com
- Fix validation of AutoYaST schema (bsc#954412)
- 3.1.6
* Thu Oct  8 2015 schubi@suse.de
- Set default value if %%is_opensuse has not been set.
  Additional fix for bnc#948563.
- 3.1.5
* Tue Oct  6 2015 schubi@suse.de
- Using %%is_opensuse in the spec file. (bnc#948563)
- 3.1.4
* Fri Jul 24 2015 locilka@suse.com
- BuildService requires an ID for package submission (bsc#939346)
- 3.1.3
* Fri Dec 19 2014 locilka@suse.com
- Replacing dropped yast2-all-packages with list of packages
  that contain RNG files needed for AutoYaST
- 3.1.2
* Wed Dec 10 2014 locilka@suse.com
- Ignoring more packages that do not contain any AutoYaST support
  during build to shorten the build cycle and to remove unneeded
  dependencies
- 3.1.1
* Thu Sep 19 2013 lslezak@suse.cz
- do not use *.spec.in template, use *.spec file with RPM macros
  instead
- 3.1.0
* Tue Jul 30 2013 yast-devel@opensuse.org
- version 3.0.0
* Tue Apr 24 2012 ug@suse.de
- fix for pxe.rnc from the autoyast package
- 2.22.0
* Tue Apr 24 2012 ug@suse.de
- added yast2-online-update-configuration to
  BUILDREQUIRES
* Tue Sep  8 2009 mvidner@suse.cz
- Build fix: Eval only X-SuSE-YaST-AutoInst*, not X-SuSE-YaST-Keywords.
- 2.18.2
* Wed Jul  8 2009 ug@suse.de
- fixed the workaround for the users rnc files
- 2.18.1
* Wed Feb 11 2009 mvidner@suse.cz
- Sort found files to avoid unnecessary rebuilds.
- 2.18.0
* Wed Oct 15 2008 ug@suse.de
- moved common.rnc from yast2-schema to autoyast2 to
  fix yast2-schema build errors
- 2.17.4
* Thu Oct  2 2008 jsrain@suse.cz
- added yast2-core to BuildRequires to build the package
- 2.17.3
* Tue Sep 30 2008 locilka@suse.cz
- Added some more BuildIgnores to build the package.
- 2.17.2
* Fri Sep 26 2008 locilka@suse.cz
- Adding some more BuildIgnores to build the package (bnc #427684).
- 2.17.1
* Tue Sep 16 2008 locilka@suse.cz
- Ignoring conflicting packages (yast2-branding-*, yast2-theme-*).
- 2.17.0
* Tue Mar 27 2007 mvidner@suse.cz
- Ignore tomcat5 while building to save time.
- 2.15.0
* Wed Nov 22 2006 mvidner@suse.cz
- Include also user_defaults and groups with users (#215249#c7).
- 2.14.2
* Tue Nov 21 2006 ug@suse.de
- for some reason the order of the elements is important
  for xmllint. This is a workaround for that problem.
  It might be a bug in xmllint and requires further
  investigation.
  (#222956)
- 2.14.1
* Mon Nov 13 2006 jsrain@suse.cz
- 2.14.0
* Mon Oct 30 2006 mvidner@suse.cz
- Fixed too aggressive escaping which broke on files-with-dashes.rnc
- 2.13.3
* Thu Feb 23 2006 mvidner@suse.cz
- converted neededforbuild to BuildRequires (mls)
- broke a build cycle with yast2-online-update (ro)
- removed yast2-devel-packages, yast2-all-packages is enough
- 2.13.2
* Mon Oct 10 2005 mvidner@suse.cz
- Added rules, classes-*, and (disabled) profile-misc.
- 2.13.1
* Fri Sep 23 2005 mvidner@suse.cz
- More documentation, renamed it so that it does not clash it with the
  copyright files.
- Do not use notAllowed, it is unclear and validators disagree.
- Allow X_SuSE_YaST_AutoInstResource and X_SuSE_YaST_AutoInstSchema to
  differ.
- Install forgotten RNC files.
- 2.13.0
* Mon Jun 13 2005 mvidner@suse.cz
- Don't install generated RNC files, they create conflicts.
- Don't distribute generated HTML docs.
- 2.12.2
* Tue Jun  7 2005 mvidner@suse.cz
- Build it in makefiles, not in the spec file.
- Build fix: trang now requires JRE.
- 2.12.1
* Tue Sep  7 2004 nashif@suse.de
- Removed nfb cycle
* Wed Aug 18 2004 nashif@suse.de
- initial version
